<?php

namespace Drupal\gridstack;

use Drupal\blazy\BlazyDefault;

/**
 * Defines shared plugin default settings for field formatter and Views style.
 *
 * @see FormatterBase::defaultSettings()
 * @see StylePluginBase::defineOptions()
 */
class GridStackDefault extends BlazyDefault {

  /**
   * {@inheritdoc}
   */
  public static function baseSettings() {
    return [
      'optionset' => 'default',
      'skin'      => '',
      'vanilla'   => FALSE,
    ] + parent::baseSettings();
  }

  /**
   * {@inheritdoc}
   */
  public static function imageSettings() {
    $settings = parent::imageSettings() + self::baseSettings();

    foreach (['breakpoints', 'responsive_image_style', 'sizes'] as $key) {
      unset($settings[$key]);
    }

    return [
      'background'  => TRUE,
      'category'    => '',
      'stamp'       => '',
      'stamp_index' => 0,
    ] + $settings;
  }

  /**
   * {@inheritdoc}
   */
  public static function extendedSettings() {
    return self::imageSettings() + parent::extendedSettings();
  }

  /**
   * Returns view fields options for Views UI.
   */
  public static function viewFieldOptions() {
    return [
      'captions',
      'layouts',
      'images',
      'links',
      'titles',
      'classes',
      'overlays',
    ];
  }

  /**
   * Returns fixed settings not configurable via UI.
   */
  public static function fixedSettings() {
    return [
      'item_id'   => 'box',
      'nameshort' => 'gs',
      'namespace' => 'gridstack',
      'ratio'     => '',
      'blazy'     => TRUE,
      'lazy'      => 'blazy',
    ];
  }

  /**
   * Returns shared global form settings which should be consumed at formatters.
   */
  public static function uiSettings() {
    return [
      'customized' => FALSE,
      'debug'      => FALSE,
      'dev'        => FALSE,
      'framework'  => '',
      'library'    => '',
      'optimized'  => FALSE,
    ];
  }

  /**
   * Returns HTML or layout related settings, none of JS to shutup notices.
   */
  public static function htmlSettings() {
    return [
      '_admin'        => FALSE,
      '_access_ipe'   => FALSE,
      '_ipe_layouts'  => FALSE,
      '_ipe_panels'   => FALSE,
      'debug'         => FALSE,
      'ungridstack'   => FALSE,
      'id'            => '',
      'lightbox'      => '',
      'nested'        => FALSE,
      'root'          => TRUE,
      'use_framework' => FALSE,
      'use_js'        => FALSE,
      'use_inner'     => TRUE,
      'wrapper'       => '',
      'view_name'     => '',
    ] + self::imageSettings() + self::fixedSettings();
  }

  /**
   * Returns breakpoints.
   */
  public static function breakpoints() {
    return [
      'xs' => 'xsmall',
      'sm' => 'small',
      'md' => 'medium',
      'lg' => 'large',
      'xl' => 'xlarge',
    ];
  }

  /**
   * Returns theme properties.
   */
  public static function themeProperties() {
    return [
      'items',
      'optionset',
      'postscript',
      'settings',
    ];
  }

}
